==> ksetiwatch-2.0.2.tar.gz: ksetiwatch-2.0.2/ksetiwatch/about.h <==
/***************************************************************************
                          about.h  -  description
                             -------------------
    begin                : Wed Dec 29 1999
    copyright            : (C) 1999 by Gordon Machel
    email                : gmachel@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ABOUT_H
#define ABOUT_H

#include <qwidget.h>
#include <qlabel.h>
#include <qscrollview.h>
#include <qpushbutton.h>

#include <kiconloader.h>

/**
  *@author Gordon Machel
  */

class About : public QWidget  {
   Q_OBJECT
public: 
	About(QWidget *parent=0, const char *name=0);
	~About();

protected: 
	void initDialog();
	void resizeEvent(QResizeEvent *e);
	QLabel* QLabel_1;
	QLabel* QLabel_2;
	QLabel* QLabel_3;
	QScrollView* info;
	QPushButton* Help;
	KIconLoader* icons;

protected slots: // Protected slots
  /** Invokes the Help window. */
  void slotShowHelp();
};

#endif

==> ksetiwatch-2.2.0.tar.gz: ksetiwatch-2.2.0/ksetiwatch/about.h <==
/***************************************************************************
                          about.h  -  description
                             -------------------
    begin                : Wed Dec 29 1999
    copyright            : (C) 1999 by Gordon Machel
    email                : gmachel@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ABOUT_H
#define ABOUT_H

#include <qwidget.h>

class KIconLoader;
class QLabel;
class QScrollView;
class QPushButton;

/**
  *@author Gordon Machel
  */

class About : public QWidget
{
Q_OBJECT

public:
	About(QWidget *parent=0, const char *name=0);
	~About();

protected: 
	void initDialog();
	void resizeEvent(QResizeEvent *e);
	QLabel* QLabel_1;
	QLabel* QLabel_2;
	QLabel* QLabel_3;
	QScrollView* info;
	QPushButton* Help;
	KIconLoader* icons;

protected slots: // Protected slots
  /** Invokes the Help window. */
  void slotShowHelp();
};

#endif
